@@ -37,7 +37,7 @@ print("Server ping:", esp.ping(HOST), "ms")
 # create the socket
 socket.set_interface(esp)
 socketaddr = socket.getaddrinfo(HOST, PORT)[0][4]
-s = socket.socket()
+s = socket.socket(type=socket.SOCK_DGRAM)
 
 s.settimeout(TIMEOUT)
 
@@ -45,7 +45,7 @@ print("Sending")
 s.connect(socketaddr, conntype=esp.UDP_MODE)
 packet = bytearray(48)
 packet[0] = 0b00100011  # Not leap second, NTP version 4, Client mode
-s.send(packet, conntype=esp.UDP_MODE)
+s.send(packet)
 
 print("Receiving")
 packet = s.recv(48)
